#!/bin/sh
# Generate all necessary files for building on the current platform
# rather than including them in cvs

#(libtoolize --version) < /dev/null > /dev/null 2>&1 || {
#        echo;
#        echo "You must have libtool installed to compile bio2jack";
#        echo;
#        exit;
#}

(gettextize --version) < /dev/null > /dev/null 2>&1 || {
        echo;
        echo "You must have gettext installed to compile bio2jack";
        echo;
        exit;
}

(automake --version) < /dev/null > /dev/null 2>&1 || {
        echo;
        echo "You must have automake installed to compile bio2jack";
        echo;
        exit;
}

(autoconf --version) < /dev/null > /dev/null 2>&1 || {
        echo;
        echo "You must have autoconf installed to compile bio2jack";
        echo;
        exit;
}


echo " Running libtoolize, please ignore non-fatal messages"
echo n|libtoolize --copy --force || exit;
echo "Generating configuration files for bio2jack, please wait..."
echo;

aclocal || exit;
autoheader || exit;
#automake --add-missing --copy;
automake --add-missing;
autoconf || exit;
automake || exit;
./configure
